pub struct InverseMPO<T: TTScalar> { /* private fields */ }Expand description
Inverse form of MPO
The inverse form is similar to Vidal form but stores inverse singular values, which is efficient for local update operations.
Implementations
Sourceimpl<T: TTScalar> InverseMPO<T>
impl<T: TTScalar> InverseMPO<T>
Sourcepub fn site_tensor(&self, i: usize) -> &Tensor4<T>
pub fn site_tensor(&self, i: usize) -> &Tensor4<T>
Get the tensor at position i
Sourcepub fn site_tensor_mut(&mut self, i: usize) -> &mut Tensor4<T>
pub fn site_tensor_mut(&mut self, i: usize) -> &mut Tensor4<T>
Get mutable reference to the tensor at position i
Sourcepub fn site_tensors(&self) -> &[Tensor4<T>] ⓘ
pub fn site_tensors(&self) -> &[Tensor4<T>] ⓘ
Get all tensors
Sourcepub fn inv_lambda(&self, i: usize) -> &[f64]
pub fn inv_lambda(&self, i: usize) -> &[f64]
Get the inverse Lambda vector at bond i (between sites i and i+1)
Sourcepub fn inv_lambdas(&self) -> &[Vec<f64>]
pub fn inv_lambdas(&self) -> &[Vec<f64>]
Get all inverse Lambda vectors