pub struct SiteMPO<T: TTScalar> { /* private fields */ }Expand description
Center-canonical form of MPO with orthogonality center
The tensors to the left of the center are left-orthogonal (left-isometric), and the tensors to the right are right-orthogonal (right-isometric).
Implementations
Sourceimpl<T: TTScalar> SiteMPO<T>
impl<T: TTScalar> SiteMPO<T>
Sourcepub fn from_mpo(mpo: MPO<T>, center: usize) -> Result<Self>
pub fn from_mpo(mpo: MPO<T>, center: usize) -> Result<Self>
Create a SiteMPO from an MPO, placing the center at the given position
Sourcepub fn site_tensor(&self, i: usize) -> &Tensor4<T>
pub fn site_tensor(&self, i: usize) -> &Tensor4<T>
Get the site tensor at position i
Sourcepub fn site_tensor_mut(&mut self, i: usize) -> &mut Tensor4<T>
pub fn site_tensor_mut(&mut self, i: usize) -> &mut Tensor4<T>
Get mutable reference to the site tensor at position i
Sourcepub fn site_tensors(&self) -> &[Tensor4<T>] ⓘ
pub fn site_tensors(&self) -> &[Tensor4<T>] ⓘ
Get all site tensors
Sourcepub fn site_tensors_mut(&mut self) -> &mut [Tensor4<T>] ⓘ
pub fn site_tensors_mut(&mut self) -> &mut [Tensor4<T>] ⓘ
Get mutable access to site tensors
Sourcepub fn move_center_left(&mut self) -> Result<()>
pub fn move_center_left(&mut self) -> Result<()>
Move the orthogonality center one position to the left
Sourcepub fn move_center_right(&mut self) -> Result<()>
pub fn move_center_right(&mut self) -> Result<()>
Move the orthogonality center one position to the right
Sourcepub fn set_center(&mut self, target: usize) -> Result<()>
pub fn set_center(&mut self, target: usize) -> Result<()>
Move the orthogonality center to the specified position