pub struct Contraction<T: SVDScalar>{ /* private fields */ }Expand description
Contraction of two MPOs with caching
This struct efficiently computes the product of two MPOs by caching left and right environments for reuse.
Implementations
Sourceimpl<T: SVDScalar> Contraction<T>
impl<T: SVDScalar> Contraction<T>
Sourcepub fn new(mpo_a: MPO<T>, mpo_b: MPO<T>) -> Result<Self>
pub fn new(mpo_a: MPO<T>, mpo_b: MPO<T>) -> Result<Self>
Create a new Contraction from two MPOs
Sourcepub fn with_transform<F>(mpo_a: MPO<T>, mpo_b: MPO<T>, f: F) -> Result<Self>
pub fn with_transform<F>(mpo_a: MPO<T>, mpo_b: MPO<T>, f: F) -> Result<Self>
Create a new Contraction with a transformation function
Sourcepub fn result_site_dims(&self) -> Vec<(usize, usize)>
pub fn result_site_dims(&self) -> Vec<(usize, usize)>
Get site dimensions for the contracted result
Returns (s1_result, s2_result) at each site where:
- s1_result = s1_a (first physical index of A)
- s2_result = s2_b (second physical index of B)
Sourcepub fn clear_cache(&mut self)
pub fn clear_cache(&mut self)
Clear all cached environments
Sourcepub fn evaluate(&mut self, indices: &[(usize, usize)]) -> Result<T>
pub fn evaluate(&mut self, indices: &[(usize, usize)]) -> Result<T>
Evaluate the contraction at a specific set of indices
indices should be [(i1, j1), (i2, j2), …] where:
- i_k is the index for s1 of MPO A at site k
- j_k is the index for s2 of MPO B at site k